ConnectivityState class

Implemented types

Constructors

ConnectivityState({required IReownCore core, required Connectivity connectivity})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isOnline → ValueNotifier<bool>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
override
init() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited