EncodingParams class

Constructors

EncodingParams(int type, Uint8List sealed, Uint8List iv, Uint8List ivSealed, {Uint8List? senderPublicKey})

Properties

hashCode → int
The hash code for this object.
no setterinherited
iv ↔ Uint8List
getter/setter pair
ivSealed ↔ Uint8List
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sealed ↔ Uint8List
getter/setter pair
senderPublicKey ↔ Uint8List?
getter/setter pair
type ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited