RegisteredFunction class

Constructors

RegisteredFunction({required String method, required dynamic function(String, JsonRpcRequest, [String?, TransportType]), required ProtocolType type})

Properties

function ↔ dynamic Function(String, JsonRpcRequest, [String?, TransportType])
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
method ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ProtocolType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited