MessageTracker class

Inheritance
Implemented types

Constructors

MessageTracker({required IStore storage, required String context, required String version, required Map<String, String> fromJson(dynamic)})

Properties

context → String
finalinherited
data ↔ Map<String, Map<String, String>>
Stores map of key to pairing info
getter/setter pairinherited
fromJson → Map<String, String> Function(dynamic)
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
onCreate → Event<StoreCreateEvent<Map<String, String>>>
Emitted when a new key is added to the store. The event contains the key and the value of type T.
finalinherited
onDelete → Event<StoreDeleteEvent<Map<String, String>>>
Emitted when a key is deleted from the store. The event contains the key and the value of type T.
finalinherited
onError → Event<StoreErrorEvent<Map<String, String>>>
Emitted when a key is deleted from the store because of an error The event contains the key and the error description.
finalinherited
onSync → Event<StoreSyncEvent>
Emitted when the store is persisted to storage. This event can be used as a catchall for any creations, updates, or deletions.
finalinherited
onUpdate → Event<StoreUpdateEvent<Map<String, String>>>
Emitted when a key is updated in some way: overwritten, some piece changes, etc. The event contains the key and the value of type T.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storage → IStore
finalinherited
storageKey → String
no setterinherited
version → String
finalinherited

Methods

checkInitialized() → void
inherited
delete(String key) → Future<void>
inherited
get(String key) → Map<String, String>?
inherited
getAll() → List<Map<String, String>>
inherited
has(String key) → bool
inherited
hashMessage(String message) → String
init() → Future<void>
inherited
messageIsRecorded(String topic, String message) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
persist() → Future<void>
inherited
recordMessageEvent(String topic, String message) → Future<void>
override
restore() → Future<void>
inherited
set(String key, Map<String, String> value) → Future<void>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited