IWebSocketHandler class abstract

Implementers

Constructors

IWebSocketHandler()

Properties

channel → StreamChannel<String>?
no setter
closeCode → int?
no setter
closeReason → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
no setter

Methods

close() → Future<void>
connect() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setup({required String url}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited