SecureStore class

Implemented types

Constructors

SecureStore({Map<String, Map<String, dynamic>>? defaultValue, required IStore<Map<String, dynamic>> fallbackStorage})

Properties

hashCode → int
The hash code for this object.
no setterinherited
keys → List<String>
no setteroverride
map → Map<String, Map<String, dynamic>>
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storagePrefix → String
no setteroverride
values → List<Map<String, dynamic>>
no setteroverride

Methods

delete(String key) → Future<void>
override
deleteAll() → Future<void>
override
get(String key) → Map<String, dynamic>?
override
getAll() → List<Map<String, dynamic>>
override
has(String key) → bool
override
init() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restore() → Future<void>
set(String key, Map<String, dynamic> value) → Future<void>
override
toString() → String
A string representation of this object.
inherited
update(String key, Map<String, dynamic> value) → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited