ReownCoreUtils class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
Static Methods
calculateExpiry (int offset )
→ int
canOpenUrl (String url )
→ Future <bool >
convertMapTo <T > (Map <String , dynamic > inMap )
→ Map <String , T >
coreSdkVersion (String sdkVersion )
→ String
ed25519Verify (PublicKey publicKey , Uint8List message , Uint8List sig )
→ bool
expiryToDateTime (int expiry )
→ DateTime
formatRelayParams (Relay relay , {String delimiter = '-' })
→ Map <String , String >
formatRelayRpcUrl ({required String protocol , required int version , required String relayUrl , required String sdkVersion , required String auth , String ? projectId , String ? packageName })
→ String
formatUA (String protocol , int version , String sdkVersion )
→ String
formatUri ({required String protocol , required String version , required String topic , required String symKey , required Relay relay , required List <List <String > > ? methods , int ? expiry })
→ Uri
getId ()
→ String
getLinkModeURL (String universalLink , String topic , String encodedEnvelope )
→ String
getOS ()
→ String
getPackageName ()
→ Future <String >
getSearchParamFromURL (String url , String param )
→ String
isExpired (int expiry )
→ bool
openURL (String url , [LaunchMode mode = LaunchMode.externalApplication ])
→ Future <bool >
parseUri (Uri uri )
→ URIParseResult
---- URI HANDLING --- ///
recursiveSearchForMapKey (Map <String , dynamic > map , String targetKey )
→ dynamic
sanitizeOSVersion (String version )
→ String
Strips literal " characters that break WalletConnect relay ua validation.
Some Windows installs return quoted product names in
Platform.operatingSystemVersion , e.g. "Windows 10 Pro" 10.0 (...).
toMilliseconds (int seconds )
→ int